@@ -44,17 +44,18 @@ Op_to_hdr_planes::state_after_conversion(const ColorState& input_state,
   output_state = input_state;
   output_state.bits_per_pixel = target_state.bits_per_pixel;
 
-  states.push_back({output_state, SpeedCosts_Unoptimized});
+  states.emplace_back(output_state, SpeedCosts_Unoptimized);
 
   return states;
 }
 
 
-std::shared_ptr<HeifPixelImage>
+Result<std::shared_ptr<HeifPixelImage>>
 Op_to_hdr_planes::convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                                      const ColorState& input_state,
                                      const ColorState& target_state,
-                                     const heif_color_conversion_options& options) const
+                                     const heif_color_conversion_options& options,
+                                     const heif_security_limits* limits) const
 {
   auto outimg = std::make_shared<HeifPixelImage>();
 
@@ -71,10 +72,10 @@ Op_to_hdr_planes::convert_colorspace(const std::shared_ptr<const HeifPixelImage>
                                heif_channel_B,
                                heif_channel_Alpha}) {
     if (input->has_channel(channel)) {
-      int width = input->get_width(channel);
-      int height = input->get_height(channel);
-      if (!outimg->add_plane(channel, width, height, target_state.bits_per_pixel)) {
-        return nullptr;
+      uint32_t width = input->get_width(channel);
+      uint32_t height = input->get_height(channel);
+      if (auto err = outimg->add_plane(channel, width, height, target_state.bits_per_pixel, limits)) {
+        return err;
       }
 
       int input_bits = input->get_bits_per_pixel(channel);
@@ -84,16 +85,16 @@ Op_to_hdr_planes::convert_colorspace(const std::shared_ptr<const HeifPixelImage>
       int shift2 = 2 * input_bits - output_bits;
 
       const uint8_t* p_in;
-      int stride_in;
+      uint32_t stride_in;
       p_in = input->get_plane(channel, &stride_in);
 
       uint16_t* p_out;
-      int stride_out;
+      uint32_t stride_out;
       p_out = (uint16_t*) outimg->get_plane(channel, &stride_out);
       stride_out /= 2;
 
-      for (int y = 0; y < height; y++)
-        for (int x = 0; x < width; x++) {
+      for (uint32_t y = 0; y < height; y++)
+        for (uint32_t x = 0; x < width; x++) {
           int in = p_in[y * stride_in + x];
           // TODO: support for <8 bpp may need more than two copies of the input bit pattern
           p_out[y * stride_out + x] = (uint16_t) ((in << shift1) | (in >> shift2));
@@ -131,17 +132,18 @@ Op_to_sdr_planes::state_after_conversion(const ColorState& input_state,
   output_state = input_state;
   output_state.bits_per_pixel = 8;
 
-  states.push_back({output_state, SpeedCosts_Unoptimized});
+  states.emplace_back(output_state, SpeedCosts_Unoptimized);
 
   return states;
 }
 
 
-std::shared_ptr<HeifPixelImage>
+Result<std::shared_ptr<HeifPixelImage>>
 Op_to_sdr_planes::convert_colorspace(const std::shared_ptr<const HeifPixelImage>& input,
                                      const ColorState& input_state,
                                      const ColorState& target_state,
-                                     const heif_color_conversion_options& options) const
+                                     const heif_color_conversion_options& options,
+                                     const heif_security_limits* limits) const
 {
 
   auto outimg = std::make_shared<HeifPixelImage>();
@@ -162,33 +164,33 @@ Op_to_sdr_planes::convert_colorspace(const std::shared_ptr<const HeifPixelImage>
       int input_bits = input->get_bits_per_pixel(channel);
 
       if (input_bits > 8) {
-        int width = input->get_width(channel);
-        int height = input->get_height(channel);
-        if (!outimg->add_plane(channel, width, height, 8)) {
-          return nullptr;
+        uint32_t width = input->get_width(channel);
+        uint32_t height = input->get_height(channel);
+        if (auto err = outimg->add_plane(channel, width, height, 8, limits)) {
+          return err;
         }
 
         int shift = input_bits - 8;
 
         const uint16_t* p_in;
-        int stride_in;
+        uint32_t stride_in;
         p_in = (uint16_t*) input->get_plane(channel, &stride_in);
         stride_in /= 2;
 
         uint8_t* p_out;
-        int stride_out;
+        uint32_t stride_out;
         p_out = outimg->get_plane(channel, &stride_out);
 
-        for (int y = 0; y < height; y++)
-          for (int x = 0; x < width; x++) {
+        for (uint32_t y = 0; y < height; y++)
+          for (uint32_t x = 0; x < width; x++) {
             int in = p_in[y * stride_in + x];
             p_out[y * stride_out + x] = (uint8_t) (in >> shift); // TODO: I think no rounding here, but am not sure.
           }
       } else if (input_bits < 8) {
-        int width = input->get_width(channel);
-        int height = input->get_height(channel);
-        if (!outimg->add_plane(channel, width, height, 8)) {
-          return nullptr;
+        uint32_t width = input->get_width(channel);
+        uint32_t height = input->get_height(channel);
+        if (auto err = outimg->add_plane(channel, width, height, 8, limits)) {
+          return err;
         }
 
         // We also want to support converting inputs with < 4 bits per pixel covering the whole output range.
@@ -203,7 +205,7 @@ Op_to_sdr_planes::convert_colorspace(const std::shared_ptr<const HeifPixelImage>
         //                   output
 
         assert(input_bits > 0 && input_bits < 8);
-        uint16_t bit = static_cast<uint16_t>(1 << (16 - input_bits));
+        auto bit = static_cast<uint16_t>(1 << (16 - input_bits));
         uint16_t mulFactor = bit;
 
         for (;;) {
@@ -215,19 +217,19 @@ Op_to_sdr_planes::convert_colorspace(const std::shared_ptr<const HeifPixelImage>
           mulFactor |= bit;
         }
 
-        int stride_in;
+        uint32_t stride_in;
         const uint8_t* p_in = input->get_plane(channel, &stride_in);
 
-        int stride_out;
+        uint32_t stride_out;
         uint8_t* p_out = outimg->get_plane(channel, &stride_out);
 
-        for (int y = 0; y < height; y++)
-          for (int x = 0; x < width; x++) {
+        for (uint32_t y = 0; y < height; y++)
+          for (uint32_t x = 0; x < width; x++) {
             int in = p_in[y * stride_in + x];
             p_out[y * stride_out + x] = (uint8_t) ((in * mulFactor) >> 8);
           }
       } else {
-        outimg->copy_new_plane_from(input, channel, channel);
+        outimg->copy_new_plane_from(input, channel, channel, limits);
       }
     }
   }
